@@ -25,7 +25,7 @@
 #include "braille.h"
 
 gint brltty_brl_open_device (gchar          *device_name, 
-			    gshort          port,
+			    const gchar     *port,
 			    BRLDevCallback  device_callback,
 			    BRLDevice       *device);
 
